Release notes
#############

This document contains the release notes for the ``ansys-tools-common``
project.

.. vale off

.. towncrier release notes start

`0.2.0 <https://github.com/ansys/pystk/releases/tag/v0.2.0>`_ - October 31, 2025
================================================================================

.. tab-set::


  .. tab-item:: Added

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Provide logger formatter separately
          - `#37 <https://github.com/ansys/pystk/pull/37>`_

        * - Feat: technical review
          - `#39 <https://github.com/ansys/pystk/pull/39>`_


  .. tab-item:: Dependencies

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Ci: bump actions/download-artifact from 4.3.0 to 5.0.0
          - `#54 <https://github.com/ansys/pystk/pull/54>`_

        * - Build: bump pytest-cov from 6.1.1 to 7.0.0
          - `#55 <https://github.com/ansys/pystk/pull/55>`_

        * - Build: bump sphinx-click from 4.4.0 to 6.1.0
          - `#59 <https://github.com/ansys/pystk/pull/59>`_

        * - Build: bump hypothesis from 6.135.10 to 6.140.3
          - `#60 <https://github.com/ansys/pystk/pull/60>`_

        * - Build: bump hypothesis from 6.142.1 to 6.142.2
          - `#69 <https://github.com/ansys/pystk/pull/69>`_


  .. tab-item:: Miscellaneous

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Ci: bump peter-evans/create-or-update-comment from 4.0.0 to 5.0.0
          - `#47 <https://github.com/ansys/pystk/pull/47>`_

        * - Ci: bump actions/labeler from 5.0.0 to 6.0.1
          - `#48 <https://github.com/ansys/pystk/pull/48>`_

        * - Build: bump pyfakefs from 5.8.0 to 5.9.3
          - `#49 <https://github.com/ansys/pystk/pull/49>`_

        * - Ci: bump actions/checkout from 4.2.2 to 5.0.0
          - `#50 <https://github.com/ansys/pystk/pull/50>`_

        * - Build: bump pytest from 8.4.0 to 8.4.2
          - `#51 <https://github.com/ansys/pystk/pull/51>`_

        * - Chore: grouping grpc dependencies in same dependabot bump
          - `#57 <https://github.com/ansys/pystk/pull/57>`_

        * - Maint: Add Dependabot automerge action
          - `#61 <https://github.com/ansys/pystk/pull/61>`_

        * - Maint: Add CI bot to CODEOWNERS
          - `#63 <https://github.com/ansys/pystk/pull/63>`_

        * - Build: bump pyfakefs from 5.9.3 to 5.10.0
          - `#64 <https://github.com/ansys/pystk/pull/64>`_

        * - Build: bump hypothesis from 6.140.3 to 6.140.4
          - `#65 <https://github.com/ansys/pystk/pull/65>`_

        * - Build: bump hypothesis from 6.140.4 to 6.141.1
          - `#66 <https://github.com/ansys/pystk/pull/66>`_

        * - Build: bump hypothesis from 6.141.1 to 6.142.1
          - `#67 <https://github.com/ansys/pystk/pull/67>`_

        * - Build: bump the grpc-deps group with 2 updates
          - `#68 <https://github.com/ansys/pystk/pull/68>`_

        * - Build: bump hypothesis from 6.142.2 to 6.142.3
          - `#71 <https://github.com/ansys/pystk/pull/71>`_

        * - Ci: bump actions/download-artifact from 5.0.0 to 6.0.0
          - `#72 <https://github.com/ansys/pystk/pull/72>`_

        * - Build: bump hypothesis from 6.142.3 to 6.142.4
          - `#73 <https://github.com/ansys/pystk/pull/73>`_

        * - Fix: Prepare for public release
          - `#74 <https://github.com/ansys/pystk/pull/74>`_


  .. tab-item:: Maintenance

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Update CHANGELOG for v0.1.0
          - `#36 <https://github.com/ansys/pystk/pull/36>`_

        * - Add \`\`ansys/actions/check-actions-security\`\` action and related fixes
          - `#41 <https://github.com/ansys/pystk/pull/41>`_


.. vale on
